# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_level": "accessLevel",
    "approvals_before_merge": "approvalsBeforeMerge",
    "author_email_regex": "authorEmailRegex",
    "branch_name_regex": "branchNameRegex",
    "branches_to_be_notified": "branchesToBeNotified",
    "can_create_group": "canCreateGroup",
    "can_push": "canPush",
    "cluster_type": "clusterType",
    "comment_on_event_enabled": "commentOnEventEnabled",
    "commit_events": "commitEvents",
    "commit_message_regex": "commitMessageRegex",
    "confidential_issue_channel": "confidentialIssueChannel",
    "confidential_issues_events": "confidentialIssuesEvents",
    "confidential_note_events": "confidentialNoteEvents",
    "container_registry_enabled": "containerRegistryEnabled",
    "create_access_level": "createAccessLevel",
    "created_at": "createdAt",
    "cron_timezone": "cronTimezone",
    "default_branch": "defaultBranch",
    "deny_delete_tag": "denyDeleteTag",
    "enable_ssl_verification": "enableSslVerification",
    "environment_scope": "environmentScope",
    "expires_at": "expiresAt",
    "file_name_regex": "fileNameRegex",
    "full_name": "fullName",
    "full_path": "fullPath",
    "group_id": "groupId",
    "http_url_to_repo": "httpUrlToRepo",
    "initialize_with_readme": "initializeWithReadme",
    "is_admin": "isAdmin",
    "is_external": "isExternal",
    "issue_channel": "issueChannel",
    "issues_enabled": "issuesEnabled",
    "issues_events": "issuesEvents",
    "jira_issue_transition_id": "jiraIssueTransitionId",
    "job_events": "jobEvents",
    "key_id": "keyId",
    "kubernetes_api_url": "kubernetesApiUrl",
    "kubernetes_authorization_type": "kubernetesAuthorizationType",
    "kubernetes_ca_cert": "kubernetesCaCert",
    "kubernetes_namespace": "kubernetesNamespace",
    "kubernetes_token": "kubernetesToken",
    "ldap_provider": "ldapProvider",
    "lfs_enabled": "lfsEnabled",
    "management_project_id": "managementProjectId",
    "max_file_size": "maxFileSize",
    "member_check": "memberCheck",
    "merge_access_level": "mergeAccessLevel",
    "merge_method": "mergeMethod",
    "merge_request_channel": "mergeRequestChannel",
    "merge_requests_enabled": "mergeRequestsEnabled",
    "merge_requests_events": "mergeRequestsEvents",
    "namespace_id": "namespaceId",
    "note_channel": "noteChannel",
    "note_events": "noteEvents",
    "notify_only_broken_pipelines": "notifyOnlyBrokenPipelines",
    "notify_only_default_branch": "notifyOnlyDefaultBranch",
    "only_allow_merge_if_all_discussions_are_resolved": "onlyAllowMergeIfAllDiscussionsAreResolved",
    "only_allow_merge_if_pipeline_succeeds": "onlyAllowMergeIfPipelineSucceeds",
    "parent_id": "parentId",
    "pipeline_channel": "pipelineChannel",
    "pipeline_events": "pipelineEvents",
    "pipeline_schedule_id": "pipelineScheduleId",
    "pipelines_enabled": "pipelinesEnabled",
    "platform_type": "platformType",
    "prevent_secrets": "preventSecrets",
    "project_id": "projectId",
    "project_key": "projectKey",
    "projects_limit": "projectsLimit",
    "provider_type": "providerType",
    "push_access_level": "pushAccessLevel",
    "push_channel": "pushChannel",
    "push_events": "pushEvents",
    "remove_source_branch_after_merge": "removeSourceBranchAfterMerge",
    "repository_url": "repositoryUrl",
    "request_access_enabled": "requestAccessEnabled",
    "reset_password": "resetPassword",
    "runners_token": "runnersToken",
    "shared_runners_enabled": "sharedRunnersEnabled",
    "shared_with_groups": "sharedWithGroups",
    "skip_confirmation": "skipConfirmation",
    "snippets_enabled": "snippetsEnabled",
    "ssh_url_to_repo": "sshUrlToRepo",
    "static_context": "staticContext",
    "tag_push_channel": "tagPushChannel",
    "tag_push_events": "tagPushEvents",
    "updated_at": "updatedAt",
    "user_id": "userId",
    "variable_type": "variableType",
    "visibility_level": "visibilityLevel",
    "web_url": "webUrl",
    "wiki_enabled": "wikiEnabled",
    "wiki_page_channel": "wikiPageChannel",
    "wiki_page_events": "wikiPageEvents",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessLevel": "access_level",
    "approvalsBeforeMerge": "approvals_before_merge",
    "authorEmailRegex": "author_email_regex",
    "branchNameRegex": "branch_name_regex",
    "branchesToBeNotified": "branches_to_be_notified",
    "canCreateGroup": "can_create_group",
    "canPush": "can_push",
    "clusterType": "cluster_type",
    "commentOnEventEnabled": "comment_on_event_enabled",
    "commitEvents": "commit_events",
    "commitMessageRegex": "commit_message_regex",
    "confidentialIssueChannel": "confidential_issue_channel",
    "confidentialIssuesEvents": "confidential_issues_events",
    "confidentialNoteEvents": "confidential_note_events",
    "containerRegistryEnabled": "container_registry_enabled",
    "createAccessLevel": "create_access_level",
    "createdAt": "created_at",
    "cronTimezone": "cron_timezone",
    "defaultBranch": "default_branch",
    "denyDeleteTag": "deny_delete_tag",
    "enableSslVerification": "enable_ssl_verification",
    "environmentScope": "environment_scope",
    "expiresAt": "expires_at",
    "fileNameRegex": "file_name_regex",
    "fullName": "full_name",
    "fullPath": "full_path",
    "groupId": "group_id",
    "httpUrlToRepo": "http_url_to_repo",
    "initializeWithReadme": "initialize_with_readme",
    "isAdmin": "is_admin",
    "isExternal": "is_external",
    "issueChannel": "issue_channel",
    "issuesEnabled": "issues_enabled",
    "issuesEvents": "issues_events",
    "jiraIssueTransitionId": "jira_issue_transition_id",
    "jobEvents": "job_events",
    "keyId": "key_id",
    "kubernetesApiUrl": "kubernetes_api_url",
    "kubernetesAuthorizationType": "kubernetes_authorization_type",
    "kubernetesCaCert": "kubernetes_ca_cert",
    "kubernetesNamespace": "kubernetes_namespace",
    "kubernetesToken": "kubernetes_token",
    "ldapProvider": "ldap_provider",
    "lfsEnabled": "lfs_enabled",
    "managementProjectId": "management_project_id",
    "maxFileSize": "max_file_size",
    "memberCheck": "member_check",
    "mergeAccessLevel": "merge_access_level",
    "mergeMethod": "merge_method",
    "mergeRequestChannel": "merge_request_channel",
    "mergeRequestsEnabled": "merge_requests_enabled",
    "mergeRequestsEvents": "merge_requests_events",
    "namespaceId": "namespace_id",
    "noteChannel": "note_channel",
    "noteEvents": "note_events",
    "notifyOnlyBrokenPipelines": "notify_only_broken_pipelines",
    "notifyOnlyDefaultBranch": "notify_only_default_branch",
    "onlyAllowMergeIfAllDiscussionsAreResolved": "only_allow_merge_if_all_discussions_are_resolved",
    "onlyAllowMergeIfPipelineSucceeds": "only_allow_merge_if_pipeline_succeeds",
    "parentId": "parent_id",
    "pipelineChannel": "pipeline_channel",
    "pipelineEvents": "pipeline_events",
    "pipelineScheduleId": "pipeline_schedule_id",
    "pipelinesEnabled": "pipelines_enabled",
    "platformType": "platform_type",
    "preventSecrets": "prevent_secrets",
    "projectId": "project_id",
    "projectKey": "project_key",
    "projectsLimit": "projects_limit",
    "providerType": "provider_type",
    "pushAccessLevel": "push_access_level",
    "pushChannel": "push_channel",
    "pushEvents": "push_events",
    "removeSourceBranchAfterMerge": "remove_source_branch_after_merge",
    "repositoryUrl": "repository_url",
    "requestAccessEnabled": "request_access_enabled",
    "resetPassword": "reset_password",
    "runnersToken": "runners_token",
    "sharedRunnersEnabled": "shared_runners_enabled",
    "sharedWithGroups": "shared_with_groups",
    "skipConfirmation": "skip_confirmation",
    "snippetsEnabled": "snippets_enabled",
    "sshUrlToRepo": "ssh_url_to_repo",
    "staticContext": "static_context",
    "tagPushChannel": "tag_push_channel",
    "tagPushEvents": "tag_push_events",
    "updatedAt": "updated_at",
    "userId": "user_id",
    "variableType": "variable_type",
    "visibilityLevel": "visibility_level",
    "webUrl": "web_url",
    "wikiEnabled": "wiki_enabled",
    "wikiPageChannel": "wiki_page_channel",
    "wikiPageEvents": "wiki_page_events",
}
